==> CoffeeMud_5_9_10.zip: com/planet_ink/coffee_mud/Items/interfaces/SpellHolder.java <==
package com.planet_ink.coffee_mud.Items.interfaces;
import java.util.List;

import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

/*
   Copyright 2004-2020 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
/**
 * A spell holder is an item that can contain spells for use in some
 * way, such as a scroll, staff, wand, pills, potions, etc.
 * @author Bo Zimmerman
 */
public interface SpellHolder extends Item
{
	/**
	 * Returns the list of ability objects that this item contains.
	 * @see SpellHolder#getSpellList()
	 * @see SpellHolder#setSpellList(String)
	 * @return the list of ability objects that this item contains
	 */
	public List<Ability> getSpells();

	/**
	 * Gets the list of abilities that this item contains as
	 * a semicolon-delimited list, with any spell arguments
	 * in parenthesis after the spell ID.
	 * @see SpellHolder#setSpellList(String)
	 * @return the list of ability names semicolon delimited
	 */
	public String getSpellList();

	/**
	 * Sets the list of abilities that this item contains as
	 * a semicolon-delimited list, with any spell arguments
	 * in parenthesis after the spell ID.
	 * @see SpellHolder#getSpellList()
	 * @param list the list of ability names semicolon delimited
	 */
	public void setSpellList(String list);
}

==> CoffeeMud_5_9_12.zip: com/planet_ink/coffee_mud/Items/interfaces/SpellHolder.java <==
package com.planet_ink.coffee_mud.Items.interfaces;
import java.util.List;

import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

/*
   Copyright 2004-2022 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
/**
 * A spell holder is an item that can contain spells for use in some
 * way, such as a scroll, staff, wand, pills, potions, etc.
 * @author Bo Zimmerman
 */
public interface SpellHolder
{
	/**
	 * Returns the list of ability objects that this item contains.
	 * @see SpellHolder#getSpellList()
	 * @see SpellHolder#setSpellList(String)
	 * @return the list of ability objects that this item contains
	 */
	public List<Ability> getSpells();

	/**
	 * Gets the list of abilities that this item contains as
	 * a semicolon-delimited list, with any spell arguments
	 * in parenthesis after the spell ID.
	 * @see SpellHolder#setSpellList(String)
	 * @return the list of ability names semicolon delimited
	 */
	public String getSpellList();

	/**
	 * Sets the list of abilities that this item contains as
	 * a semicolon-delimited list, with any spell arguments
	 * in parenthesis after the spell ID.
	 * @see SpellHolder#getSpellList()
	 * @param list the list of ability names semicolon delimited
	 */
	public void setSpellList(String list);
}
